@@ -42,3 +42,16 @@ Should be valid
 
 //nolint:staticcheck // nolint should be in the default list of acceptable comments.
 var b string
+
+type c struct {
+	//+optional
+	d *int `json:"d,omitempty"`
+}
+
+//extern open
+//export MyFunction
+
+//nolint:gochecknoglobals
+
+//this is a regular command that's incorrectly formatted //nolint:foobar // because one two three
+// MATCH:56 /no space between comment delimiter and comment text/
