@@ -11,6 +11,7 @@ import (
 	"errors"
 	"fmt"
 	"io"
+	"mime"
 	"mime/multipart"
 	"net/http"
 	"os"
@@ -283,6 +284,13 @@ func MIMEMultipartReadFrom(r io.Reader, boundary string, maxMemory int64) {
 	}
 }
 
+func MimeParseMediaType(contentType string) {
+	_, _, err := mime.ParseMediaType(contentType)
+	if err == mime.ErrInvalidMediaParameter {
+		fmt.Println(err)
+	}
+}
+
 func SyscallErrors() {
 	err := syscall.Chmod("/dev/null", 0666)
 	if err == syscall.EINVAL {
